# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKQuadEdgeMeshPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkGeometricalQuadEdgePython
else:
    import _itkGeometricalQuadEdgePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkQuadEdgePython
import itk.pyBasePython
class itkGeometricalQuadEdgeULULBBF(itk.itkQuadEdgePython.itkQuadEdge):
    r"""Proxy of C++ itkGeometricalQuadEdgeULULBBF class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def BeginGeomOnext(self, *args):
        r"""
        BeginGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomOnext(self, *args)

    def EndGeomOnext(self, *args):
        r"""
        EndGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomOnext(self, *args)

    def BeginGeomSym(self, *args):
        r"""
        BeginGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomSym(self, *args)

    def EndGeomSym(self, *args):
        r"""
        EndGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomSym(self, *args)

    def BeginGeomLnext(self, *args):
        r"""
        BeginGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomLnext(self, *args)

    def EndGeomLnext(self, *args):
        r"""
        EndGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomLnext(self, *args)

    def BeginGeomRnext(self, *args):
        r"""
        BeginGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomRnext(self, *args)

    def EndGeomRnext(self, *args):
        r"""
        EndGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomRnext(self, *args)

    def BeginGeomDnext(self, *args):
        r"""
        BeginGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomDnext(self, *args)

    def EndGeomDnext(self, *args):
        r"""
        EndGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomDnext(self, *args)

    def BeginGeomOprev(self, *args):
        r"""
        BeginGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomOprev(self, *args)

    def EndGeomOprev(self, *args):
        r"""
        EndGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomOprev(self, *args)

    def BeginGeomLprev(self, *args):
        r"""
        BeginGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomLprev(self, *args)

    def EndGeomLprev(self, *args):
        r"""
        EndGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomLprev(self, *args)

    def BeginGeomRprev(self, *args):
        r"""
        BeginGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomRprev(self, *args)

    def EndGeomRprev(self, *args):
        r"""
        EndGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomRprev(self, *args)

    def BeginGeomDprev(self, *args):
        r"""
        BeginGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomDprev(self, *args)

    def EndGeomDprev(self, *args):
        r"""
        EndGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomDprev(self, *args)

    def BeginGeomInvOnext(self, *args):
        r"""
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomInvOnext(self, *args)

    def EndGeomInvOnext(self, *args):
        r"""
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomInvOnext(self, *args)

    def BeginGeomInvLnext(self, *args):
        r"""
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomInvLnext(self, *args)

    def EndGeomInvLnext(self, *args):
        r"""
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomInvLnext(self, *args)

    def BeginGeomInvRnext(self, *args):
        r"""
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomInvRnext(self, *args)

    def EndGeomInvRnext(self, *args):
        r"""
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomInvRnext(self, *args)

    def BeginGeomInvDnext(self, *args):
        r"""
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_BeginGeomInvDnext(self, *args)

    def EndGeomInvDnext(self, *args):
        r"""
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_EndGeomInvDnext(self, *args)

    def GetOnext(self, *args):
        r"""
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetOnext(self, *args)

    def GetRot(self, *args):
        r"""
        GetRot(self) -> itkGeometricalQuadEdgeULULBBT
        GetRot(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetRot(self, *args)

    def GetSym(self, *args):
        r"""
        GetSym(self) -> itkGeometricalQuadEdgeULULBBF
        GetSym(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetSym(self, *args)

    def GetLnext(self, *args):
        r"""
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetLnext(self, *args)

    def GetRnext(self, *args):
        r"""
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetRnext(self, *args)

    def GetDnext(self, *args):
        r"""
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetDnext(self, *args)

    def GetOprev(self, *args):
        r"""
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetOprev(self, *args)

    def GetLprev(self, *args):
        r"""
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetLprev(self, *args)

    def GetRprev(self, *args):
        r"""
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetRprev(self, *args)

    def GetDprev(self, *args):
        r"""
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetDprev(self, *args)

    def GetInvRot(self, *args):
        r"""
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetInvRot(self, *args)

    def GetInvOnext(self, *args):
        r"""
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetInvOnext(self, *args)

    def GetInvLnext(self, *args):
        r"""
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetInvLnext(self, *args)

    def GetInvRnext(self, *args):
        r"""
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetInvRnext(self, *args)

    def GetInvDnext(self, *args):
        r"""
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetInvDnext(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkGeometricalQuadEdgeULULBBF
        __init__(self, arg0) -> itkGeometricalQuadEdgeULULBBF

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF const &

        """
        _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_swiginit(self, _itkGeometricalQuadEdgePython.new_itkGeometricalQuadEdgeULULBBF(*args))
    __swig_destroy__ = _itkGeometricalQuadEdgePython.delete_itkGeometricalQuadEdgeULULBBF

    def SetOrigin(self, v):
        r"""
        SetOrigin(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetOrigin(self, v)

    def SetDestination(self, v):
        r"""
        SetDestination(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetDestination(self, v)

    def SetRight(self, v):
        r"""
        SetRight(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetRight(self, v)

    def SetLeft(self, v):
        r"""
        SetLeft(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetLeft(self, v)

    def SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100):
        r"""
        SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100) -> bool

        Parameters
        ----------
        faceGeom: unsigned long const
        maxSize: int

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetLnextRingWithSameLeftFace(self, faceGeom, maxSize)

    def UnsetOrigin(self):
        r"""UnsetOrigin(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_UnsetOrigin(self)

    def UnsetDestination(self):
        r"""UnsetDestination(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_UnsetDestination(self)

    def UnsetRight(self):
        r"""UnsetRight(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_UnsetRight(self)

    def UnsetLeft(self):
        r"""UnsetLeft(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_UnsetLeft(self)

    def GetOrigin(self):
        r"""GetOrigin(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetOrigin(self)

    def GetDestination(self):
        r"""GetDestination(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetDestination(self)

    def GetRight(self):
        r"""GetRight(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetRight(self)

    def GetLeft(self):
        r"""GetLeft(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetLeft(self)

    def IsOriginSet(self):
        r"""IsOriginSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsOriginSet(self)

    def IsDestinationSet(self):
        r"""IsDestinationSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsDestinationSet(self)

    def IsRightSet(self):
        r"""IsRightSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsRightSet(self)

    def IsLeftSet(self):
        r"""IsLeftSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsLeftSet(self)

    def SetPrimalData(self, *args):
        r"""
        SetPrimalData(self, data)

        Parameters
        ----------
        data: bool const

        SetPrimalData(self)
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetPrimalData(self, *args)

    def SetDualData(self, *args):
        r"""
        SetDualData(self, data)

        Parameters
        ----------
        data: bool const

        SetDualData(self)
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetDualData(self, *args)

    def UnsetPrimalData(self):
        r"""UnsetPrimalData(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_UnsetPrimalData(self)

    def UnsetDualData(self):
        r"""UnsetDualData(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_UnsetDualData(self)

    def GetPrimalData(self):
        r"""GetPrimalData(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetPrimalData(self)

    def GetDualData(self):
        r"""GetDualData(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetDualData(self)

    def IsPrimalDataSet(self):
        r"""IsPrimalDataSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsPrimalDataSet(self)

    def IsDualDataSet(self):
        r"""IsDualDataSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsDualDataSet(self)

    def IsWire(self):
        r"""IsWire(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsWire(self)

    def IsAtBorder(self):
        r"""IsAtBorder(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsAtBorder(self)

    def IsInternal(self):
        r"""IsInternal(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsInternal(self)

    def IsOriginInternal(self):
        r"""IsOriginInternal(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsOriginInternal(self)

    def IsLnextSharingSameFace(self, maxSize=100):
        r"""
        IsLnextSharingSameFace(self, maxSize=100) -> bool

        Parameters
        ----------
        maxSize: int

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsLnextSharingSameFace(self, maxSize)

    def IsLnextOfTriangle(self):
        r"""IsLnextOfTriangle(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsLnextOfTriangle(self)

    def IsInOnextRing(self, arg0):
        r"""
        IsInOnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsInOnextRing(self, arg0)

    def IsInLnextRing(self, arg0):
        r"""
        IsInLnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsInLnextRing(self, arg0)

    def GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None):
        r"""
        GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None) -> itkGeometricalQuadEdgeULULBBF

        Parameters
        ----------
        edgeTest: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetNextBorderEdgeWithUnsetLeft(self, edgeTest)

    def InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None):
        r"""
        InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None) -> bool

        Parameters
        ----------
        isol: itkGeometricalQuadEdgeULULBBF *
        hint: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint)

    def ReorderOnextRingBeforeAddFace(self, second):
        r"""
        ReorderOnextRingBeforeAddFace(self, second) -> bool

        Parameters
        ----------
        second: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_ReorderOnextRingBeforeAddFace(self, second)

    def IsOriginDisconnected(self):
        r"""IsOriginDisconnected(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsOriginDisconnected(self)

    def IsDestinationDisconnected(self):
        r"""IsDestinationDisconnected(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsDestinationDisconnected(self)

    def IsDisconnected(self):
        r"""IsDisconnected(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_IsDisconnected(self)

    def Disconnect(self):
        r"""Disconnect(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_Disconnect(self)

    def SetIdent(self, User_Value):
        r"""
        SetIdent(self, User_Value)

        Parameters
        ----------
        User_Value: unsigned long const &

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_SetIdent(self, User_Value)

    def GetIdent(self):
        r"""GetIdent(self) -> unsigned long"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_GetIdent(self)

# Register itkGeometricalQuadEdgeULULBBF in _itkGeometricalQuadEdgePython:
_itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF_swigregister(itkGeometricalQuadEdgeULULBBF)
class itkGeometricalQuadEdgeULULBBT(itk.itkQuadEdgePython.itkQuadEdge):
    r"""Proxy of C++ itkGeometricalQuadEdgeULULBBT class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def BeginGeomOnext(self, *args):
        r"""
        BeginGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomOnext(self, *args)

    def EndGeomOnext(self, *args):
        r"""
        EndGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomOnext(self, *args)

    def BeginGeomSym(self, *args):
        r"""
        BeginGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomSym(self, *args)

    def EndGeomSym(self, *args):
        r"""
        EndGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomSym(self, *args)

    def BeginGeomLnext(self, *args):
        r"""
        BeginGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomLnext(self, *args)

    def EndGeomLnext(self, *args):
        r"""
        EndGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomLnext(self, *args)

    def BeginGeomRnext(self, *args):
        r"""
        BeginGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomRnext(self, *args)

    def EndGeomRnext(self, *args):
        r"""
        EndGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomRnext(self, *args)

    def BeginGeomDnext(self, *args):
        r"""
        BeginGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomDnext(self, *args)

    def EndGeomDnext(self, *args):
        r"""
        EndGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomDnext(self, *args)

    def BeginGeomOprev(self, *args):
        r"""
        BeginGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomOprev(self, *args)

    def EndGeomOprev(self, *args):
        r"""
        EndGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomOprev(self, *args)

    def BeginGeomLprev(self, *args):
        r"""
        BeginGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomLprev(self, *args)

    def EndGeomLprev(self, *args):
        r"""
        EndGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomLprev(self, *args)

    def BeginGeomRprev(self, *args):
        r"""
        BeginGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomRprev(self, *args)

    def EndGeomRprev(self, *args):
        r"""
        EndGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomRprev(self, *args)

    def BeginGeomDprev(self, *args):
        r"""
        BeginGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomDprev(self, *args)

    def EndGeomDprev(self, *args):
        r"""
        EndGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomDprev(self, *args)

    def BeginGeomInvOnext(self, *args):
        r"""
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomInvOnext(self, *args)

    def EndGeomInvOnext(self, *args):
        r"""
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomInvOnext(self, *args)

    def BeginGeomInvLnext(self, *args):
        r"""
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomInvLnext(self, *args)

    def EndGeomInvLnext(self, *args):
        r"""
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomInvLnext(self, *args)

    def BeginGeomInvRnext(self, *args):
        r"""
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomInvRnext(self, *args)

    def EndGeomInvRnext(self, *args):
        r"""
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomInvRnext(self, *args)

    def BeginGeomInvDnext(self, *args):
        r"""
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_BeginGeomInvDnext(self, *args)

    def EndGeomInvDnext(self, *args):
        r"""
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool,false > >
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_EndGeomInvDnext(self, *args)

    def GetOnext(self, *args):
        r"""
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetOnext(self, *args)

    def GetRot(self, *args):
        r"""
        GetRot(self) -> itkGeometricalQuadEdgeULULBBF
        GetRot(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetRot(self, *args)

    def GetSym(self, *args):
        r"""
        GetSym(self) -> itkGeometricalQuadEdgeULULBBT
        GetSym(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetSym(self, *args)

    def GetLnext(self, *args):
        r"""
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetLnext(self, *args)

    def GetRnext(self, *args):
        r"""
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetRnext(self, *args)

    def GetDnext(self, *args):
        r"""
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetDnext(self, *args)

    def GetOprev(self, *args):
        r"""
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBT
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetOprev(self, *args)

    def GetLprev(self, *args):
        r"""
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBT
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetLprev(self, *args)

    def GetRprev(self, *args):
        r"""
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBT
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetRprev(self, *args)

    def GetDprev(self, *args):
        r"""
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBT
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetDprev(self, *args)

    def GetInvRot(self, *args):
        r"""
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetInvRot(self, *args)

    def GetInvOnext(self, *args):
        r"""
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetInvOnext(self, *args)

    def GetInvLnext(self, *args):
        r"""
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetInvLnext(self, *args)

    def GetInvRnext(self, *args):
        r"""
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetInvRnext(self, *args)

    def GetInvDnext(self, *args):
        r"""
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetInvDnext(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkGeometricalQuadEdgeULULBBT
        __init__(self, arg0) -> itkGeometricalQuadEdgeULULBBT

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBT const &

        """
        _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_swiginit(self, _itkGeometricalQuadEdgePython.new_itkGeometricalQuadEdgeULULBBT(*args))
    __swig_destroy__ = _itkGeometricalQuadEdgePython.delete_itkGeometricalQuadEdgeULULBBT

    def SetOrigin(self, v):
        r"""
        SetOrigin(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetOrigin(self, v)

    def SetDestination(self, v):
        r"""
        SetDestination(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetDestination(self, v)

    def SetRight(self, v):
        r"""
        SetRight(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetRight(self, v)

    def SetLeft(self, v):
        r"""
        SetLeft(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetLeft(self, v)

    def SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100):
        r"""
        SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100) -> bool

        Parameters
        ----------
        faceGeom: unsigned long const
        maxSize: int

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetLnextRingWithSameLeftFace(self, faceGeom, maxSize)

    def UnsetOrigin(self):
        r"""UnsetOrigin(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_UnsetOrigin(self)

    def UnsetDestination(self):
        r"""UnsetDestination(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_UnsetDestination(self)

    def UnsetRight(self):
        r"""UnsetRight(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_UnsetRight(self)

    def UnsetLeft(self):
        r"""UnsetLeft(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_UnsetLeft(self)

    def GetOrigin(self):
        r"""GetOrigin(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetOrigin(self)

    def GetDestination(self):
        r"""GetDestination(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetDestination(self)

    def GetRight(self):
        r"""GetRight(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetRight(self)

    def GetLeft(self):
        r"""GetLeft(self) -> unsigned long const"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetLeft(self)

    def IsOriginSet(self):
        r"""IsOriginSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsOriginSet(self)

    def IsDestinationSet(self):
        r"""IsDestinationSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsDestinationSet(self)

    def IsRightSet(self):
        r"""IsRightSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsRightSet(self)

    def IsLeftSet(self):
        r"""IsLeftSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsLeftSet(self)

    def SetPrimalData(self, *args):
        r"""
        SetPrimalData(self, data)

        Parameters
        ----------
        data: bool const

        SetPrimalData(self)
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetPrimalData(self, *args)

    def SetDualData(self, *args):
        r"""
        SetDualData(self, data)

        Parameters
        ----------
        data: bool const

        SetDualData(self)
        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetDualData(self, *args)

    def UnsetPrimalData(self):
        r"""UnsetPrimalData(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_UnsetPrimalData(self)

    def UnsetDualData(self):
        r"""UnsetDualData(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_UnsetDualData(self)

    def GetPrimalData(self):
        r"""GetPrimalData(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetPrimalData(self)

    def GetDualData(self):
        r"""GetDualData(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetDualData(self)

    def IsPrimalDataSet(self):
        r"""IsPrimalDataSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsPrimalDataSet(self)

    def IsDualDataSet(self):
        r"""IsDualDataSet(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsDualDataSet(self)

    def IsWire(self):
        r"""IsWire(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsWire(self)

    def IsAtBorder(self):
        r"""IsAtBorder(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsAtBorder(self)

    def IsInternal(self):
        r"""IsInternal(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsInternal(self)

    def IsOriginInternal(self):
        r"""IsOriginInternal(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsOriginInternal(self)

    def IsLnextSharingSameFace(self, maxSize=100):
        r"""
        IsLnextSharingSameFace(self, maxSize=100) -> bool

        Parameters
        ----------
        maxSize: int

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsLnextSharingSameFace(self, maxSize)

    def IsLnextOfTriangle(self):
        r"""IsLnextOfTriangle(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsLnextOfTriangle(self)

    def IsInOnextRing(self, arg0):
        r"""
        IsInOnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBT *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsInOnextRing(self, arg0)

    def IsInLnextRing(self, arg0):
        r"""
        IsInLnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBT *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsInLnextRing(self, arg0)

    def GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None):
        r"""
        GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None) -> itkGeometricalQuadEdgeULULBBT

        Parameters
        ----------
        edgeTest: itkGeometricalQuadEdgeULULBBT *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetNextBorderEdgeWithUnsetLeft(self, edgeTest)

    def InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None):
        r"""
        InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None) -> bool

        Parameters
        ----------
        isol: itkGeometricalQuadEdgeULULBBT *
        hint: itkGeometricalQuadEdgeULULBBT *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint)

    def ReorderOnextRingBeforeAddFace(self, second):
        r"""
        ReorderOnextRingBeforeAddFace(self, second) -> bool

        Parameters
        ----------
        second: itkGeometricalQuadEdgeULULBBT *

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_ReorderOnextRingBeforeAddFace(self, second)

    def IsOriginDisconnected(self):
        r"""IsOriginDisconnected(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsOriginDisconnected(self)

    def IsDestinationDisconnected(self):
        r"""IsDestinationDisconnected(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsDestinationDisconnected(self)

    def IsDisconnected(self):
        r"""IsDisconnected(self) -> bool"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_IsDisconnected(self)

    def Disconnect(self):
        r"""Disconnect(self)"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_Disconnect(self)

    def SetIdent(self, User_Value):
        r"""
        SetIdent(self, User_Value)

        Parameters
        ----------
        User_Value: unsigned long const &

        """
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_SetIdent(self, User_Value)

    def GetIdent(self):
        r"""GetIdent(self) -> unsigned long"""
        return _itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_GetIdent(self)

# Register itkGeometricalQuadEdgeULULBBT in _itkGeometricalQuadEdgePython:
_itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBT_swigregister(itkGeometricalQuadEdgeULULBBT)

